==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/ImageStreamSpecFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface ImageStreamSpecFluent<A extends io.fabric8.openshift.api.model.ImageStreamSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getDockerImageRepository();
  public A withDockerImageRepository(java.lang.String dockerImageRepository);
  public java.lang.Boolean hasDockerImageRepository();
  
  /**
   * Method is deprecated. use withDockerImageRepository instead.
   */
  @java.lang.Deprecated
  public A withNewDockerImageRepository(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildLookupPolicy instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ImageLookupPolicy getLookupPolicy();
  public io.fabric8.openshift.api.model.ImageLookupPolicy buildLookupPolicy();
  public A withLookupPolicy(io.fabric8.openshift.api.model.ImageLookupPolicy lookupPolicy);
  public java.lang.Boolean hasLookupPolicy();
  public A withNewLookupPolicy(java.lang.Boolean local);
  public io.fabric8.openshift.api.model.ImageStreamSpecFluent.LookupPolicyNested<A> withNewLookupPolicy();
  public io.fabric8.openshift.api.model.ImageStreamSpecFluent.LookupPolicyNested<A> withNewLookupPolicyLike(io.fabric8.openshift.api.model.ImageLookupPolicy item);
  public io.fabric8.openshift.api.model.ImageStreamSpecFluent.LookupPolicyNested<A> editLookupPolicy();
  public io.fabric8.openshift.api.model.ImageStreamSpecFluent.LookupPolicyNested<A> editOrNewLookupPolicy();
  public io.fabric8.openshift.api.model.ImageStreamSpecFluent.LookupPolicyNested<A> editOrNewLookupPolicyLike(io.fabric8.openshift.api.model.ImageLookupPolicy item);
  public A addToTags(java.lang.Integer index,io.fabric8.openshift.api.model.TagReference item);
  public A setToTags(java.lang.Integer index,io.fabric8.openshift.api.model.TagReference item);
  public A addToTags(io.fabric8.openshift.api.model.TagReference... items);
  public A addAllToTags(java.util.Collection<io.fabric8.openshift.api.model.TagReference> items);
  public A removeFromTags(io.fabric8.openshift.api.model.TagReference... items);
  public A removeAllFromTags(java.util.Collection<io.fabric8.openshift.api.model.TagReference> items);
  public A removeMatchingFromTags(java.util.function.Predicate<io.fabric8.openshift.api.model.TagReferenceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildTags instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.TagReference> getTags();
  public java.util.List<io.fabric8.openshift.api.model.TagReference> buildTags();
  public io.fabric8.openshift.api.model.TagReference buildTag(java.lang.Integer index);
  public io.fabric8.openshift.api.model.TagReference buildFirstTag();
  public io.fabric8.openshift.api.model.TagReference buildLastTag();
  public io.fabric8.openshift.api.model.TagReference buildMatchingTag(java.util.function.Predicate<io.fabric8.openshift.api.model.TagReferenceBuilder> predicate);
  public java.lang.Boolean hasMatchingTag(java.util.function.Predicate<io.fabric8.openshift.api.model.TagReferenceBuilder> predicate);
  public A withTags(java.util.List<io.fabric8.openshift.api.model.TagReference> tags);
  public A withTags(io.fabric8.openshift.api.model.TagReference... tags);
  public java.lang.Boolean hasTags();
  public io.fabric8.openshift.api.model.ImageStreamSpecFluent.TagsNested<A> addNewTag();
  public io.fabric8.openshift.api.model.ImageStreamSpecFluent.TagsNested<A> addNewTagLike(io.fabric8.openshift.api.model.TagReference item);
  public io.fabric8.openshift.api.model.ImageStreamSpecFluent.TagsNested<A> setNewTagLike(java.lang.Integer index,io.fabric8.openshift.api.model.TagReference item);
  public io.fabric8.openshift.api.model.ImageStreamSpecFluent.TagsNested<A> editTag(java.lang.Integer index);
  public io.fabric8.openshift.api.model.ImageStreamSpecFluent.TagsNested<A> editFirstTag();
  public io.fabric8.openshift.api.model.ImageStreamSpecFluent.TagsNested<A> editLastTag();
  public io.fabric8.openshift.api.model.ImageStreamSpecFluent.TagsNested<A> editMatchingTag(java.util.function.Predicate<io.fabric8.openshift.api.model.TagReferenceBuilder> predicate);
  public interface LookupPolicyNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.ImageLookupPolicyFluent<io.fabric8.openshift.api.model.ImageStreamSpecFluent.LookupPolicyNested<N>>{
    public N and();
    public N endLookupPolicy();
    
  }
  public interface TagsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.TagReferenceFluent<io.fabric8.openshift.api.model.ImageStreamSpecFluent.TagsNested<N>>{
    public N and();
    public N endTag();
    
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/ImageStreamSpecFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface ImageStreamSpecFluent<A extends io.fabric8.openshift.api.model.ImageStreamSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getDockerImageRepository();
  public A withDockerImageRepository(java.lang.String dockerImageRepository);
  public java.lang.Boolean hasDockerImageRepository();
  
  /**
   * Method is deprecated. use withDockerImageRepository instead.
   */
  @java.lang.Deprecated
  public A withNewDockerImageRepository(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildLookupPolicy instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ImageLookupPolicy getLookupPolicy();
  public io.fabric8.openshift.api.model.ImageLookupPolicy buildLookupPolicy();
  public A withLookupPolicy(io.fabric8.openshift.api.model.ImageLookupPolicy lookupPolicy);
  public java.lang.Boolean hasLookupPolicy();
  public A withNewLookupPolicy(java.lang.Boolean local);
  public io.fabric8.openshift.api.model.ImageStreamSpecFluent.LookupPolicyNested<A> withNewLookupPolicy();
  public io.fabric8.openshift.api.model.ImageStreamSpecFluent.LookupPolicyNested<A> withNewLookupPolicyLike(io.fabric8.openshift.api.model.ImageLookupPolicy item);
  public io.fabric8.openshift.api.model.ImageStreamSpecFluent.LookupPolicyNested<A> editLookupPolicy();
  public io.fabric8.openshift.api.model.ImageStreamSpecFluent.LookupPolicyNested<A> editOrNewLookupPolicy();
  public io.fabric8.openshift.api.model.ImageStreamSpecFluent.LookupPolicyNested<A> editOrNewLookupPolicyLike(io.fabric8.openshift.api.model.ImageLookupPolicy item);
  public A addToTags(java.lang.Integer index,io.fabric8.openshift.api.model.TagReference item);
  public A setToTags(java.lang.Integer index,io.fabric8.openshift.api.model.TagReference item);
  public A addToTags(io.fabric8.openshift.api.model.TagReference... items);
  public A addAllToTags(java.util.Collection<io.fabric8.openshift.api.model.TagReference> items);
  public A removeFromTags(io.fabric8.openshift.api.model.TagReference... items);
  public A removeAllFromTags(java.util.Collection<io.fabric8.openshift.api.model.TagReference> items);
  public A removeMatchingFromTags(java.util.function.Predicate<io.fabric8.openshift.api.model.TagReferenceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildTags instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.TagReference> getTags();
  public java.util.List<io.fabric8.openshift.api.model.TagReference> buildTags();
  public io.fabric8.openshift.api.model.TagReference buildTag(java.lang.Integer index);
  public io.fabric8.openshift.api.model.TagReference buildFirstTag();
  public io.fabric8.openshift.api.model.TagReference buildLastTag();
  public io.fabric8.openshift.api.model.TagReference buildMatchingTag(java.util.function.Predicate<io.fabric8.openshift.api.model.TagReferenceBuilder> predicate);
  public java.lang.Boolean hasMatchingTag(java.util.function.Predicate<io.fabric8.openshift.api.model.TagReferenceBuilder> predicate);
  public A withTags(java.util.List<io.fabric8.openshift.api.model.TagReference> tags);
  public A withTags(io.fabric8.openshift.api.model.TagReference... tags);
  public java.lang.Boolean hasTags();
  public io.fabric8.openshift.api.model.ImageStreamSpecFluent.TagsNested<A> addNewTag();
  public io.fabric8.openshift.api.model.ImageStreamSpecFluent.TagsNested<A> addNewTagLike(io.fabric8.openshift.api.model.TagReference item);
  public io.fabric8.openshift.api.model.ImageStreamSpecFluent.TagsNested<A> setNewTagLike(java.lang.Integer index,io.fabric8.openshift.api.model.TagReference item);
  public io.fabric8.openshift.api.model.ImageStreamSpecFluent.TagsNested<A> editTag(java.lang.Integer index);
  public io.fabric8.openshift.api.model.ImageStreamSpecFluent.TagsNested<A> editFirstTag();
  public io.fabric8.openshift.api.model.ImageStreamSpecFluent.TagsNested<A> editLastTag();
  public io.fabric8.openshift.api.model.ImageStreamSpecFluent.TagsNested<A> editMatchingTag(java.util.function.Predicate<io.fabric8.openshift.api.model.TagReferenceBuilder> predicate);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface LookupPolicyNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.ImageLookupPolicyFluent<io.fabric8.openshift.api.model.ImageStreamSpecFluent.LookupPolicyNested<N>>{
    public N and();
    public N endLookupPolicy();
    
  }
  public interface TagsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.TagReferenceFluent<io.fabric8.openshift.api.model.ImageStreamSpecFluent.TagsNested<N>>{
    public N and();
    public N endTag();
    
  }
  
}
